@@ -6,11 +6,11 @@ import tempfile
 
 import click
 from click.exceptions import ClickException
-
 from queenbee.cli.context import Context as QueenbeeContext
 from queenbee.plugin.plugin import Plugin
 import yaml
 
+from queenbee_pollination.cli.push import recipe, plugin
 
 from pollination_dsl.package import translate, load, _get_package_readme, \
     _get_package_owner
@@ -27,14 +27,8 @@ def main():
 @click.pass_context
 def dsl(ctx):
     """Pollination python DSL plugin."""
-    try:
-        import queenbee_pollination
-    except ImportError:
-        # no queenbee pollination installed
-        pass
-    else:
-        from queenbee_pollination.cli.context import Context
-        ctx.obj = Context()
+    from queenbee_pollination.cli.context import Context
+    ctx.obj = Context()
 
 
 @dsl.command('translate')
@@ -96,8 +90,8 @@ def translate_recipe(ctx, recipe_name, target_folder, queenbee):
     '-e', '--endpoint', help='Endpoint to push the resource.', show_default=True,
     default='https://api.pollination.cloud'
 )
-# TODO: Add better support for mapping dependencies to sources. For now it is all
-# set to the same value which is fine for our use cases.
+# TODO: Add better support for mapping different dependencies to different sources. For
+# now it is all set to the same value which is fine for our use cases.
 @click.option(
     '-src', '--source', help='A link to replace the source for dependencies. This value '
     'will overwrite the source value in recipe\'s dependencies files. By default it '
@@ -108,12 +102,16 @@ def translate_recipe(ctx, recipe_name, target_folder, queenbee):
     'a public or a private resource. This option does not change the visibility of a '
     'resource if it already exist.', is_flag=True, default=True
 )
+@click.option(
+    '--tag', '-t', help='An optional tag to enforce tag number. By default the tag will '
+    'be extracted from package version.',
+)
 @click.option(
     '--dry-run', '-dr', help='An option to test the command and export the package to '
     'a folder without pushing it to endpoint.', is_flag=True, default=False
 )
 @click.pass_context
-def push_resource(ctx, package_name, owner, endpoint, source, public, dry_run):
+def push_resource(ctx, package_name, endpoint, source, public, tag, dry_run):
     """Push a pollination dsl recipe or plugin to Pollination.
 
     To run this command you need queenbee-pollination[cli] installed. You can also
@@ -125,13 +123,6 @@ def push_resource(ctx, package_name, owner, endpoint, source, public, dry_run):
             Python package.
 
     """
-    try:
-        from queenbee_pollination.cli.push import recipe, plugin
-    except ImportError:
-        raise ImportError(
-            'Failed to import queenbee_pollination. Try running '
-            '`pip install pollination-dsl[pollination]` command.'
-        )
     # set the config vars
     ctx.obj.config.endpoint = endpoint
     ctx.obj.config.token = os.getenv('QB_POLLINATION_TOKEN')
@@ -160,11 +151,15 @@ def push_resource(ctx, package_name, owner, endpoint, source, public, dry_run):
     # write to a folder
     temp_dir = tempfile.mkdtemp()
     folder = pathlib.Path(temp_dir, sub_folder)
+
     resource.to_folder(
         folder_path=folder,
         readme_string=_get_package_readme(package_name)
     )
-    tag = resource.metadata.tag
+
+    if tag is None:
+        tag = resource.metadata.tag
+
     # overwite resources in dependencies
     if resource_type == 'recipe':
         source = source or 'https://api.pollination.cloud/registries'
